@@ -502,7 +502,8 @@ gst_ffmpegviddec_set_format (GstVideoDecoder * decoder,
 done:
   GST_OBJECT_UNLOCK (ffmpegdec);
 
-  gst_video_decoder_set_latency (decoder, latency, latency);
+  if (GST_CLOCK_TIME_IS_VALID (latency))
+    gst_video_decoder_set_latency (decoder, latency, latency);
 
   return ret;
 
@@ -1339,8 +1340,8 @@ gst_ffmpegviddec_handle_frame (GstVideoDecoder * decoder,
   bdata = minfo.data;
   bsize = minfo.size;
 
-  if (!GST_MEMORY_IS_ZERO_PADDED (minfo.memory)
-      || (minfo.maxsize - minfo.size) < FF_INPUT_BUFFER_PADDING_SIZE) {
+  if (bsize > 0 && (!GST_MEMORY_IS_ZERO_PADDED (minfo.memory)
+          || (minfo.maxsize - minfo.size) < FF_INPUT_BUFFER_PADDING_SIZE)) {
     /* add padding */
     if (ffmpegdec->padded_size < bsize + FF_INPUT_BUFFER_PADDING_SIZE) {
       ffmpegdec->padded_size = bsize + FF_INPUT_BUFFER_PADDING_SIZE;
@@ -1689,10 +1690,9 @@ gst_ffmpegviddec_register (GstPlugin * plugin)
     gchar *type_name;
     gchar *plugin_name;
 
-    /* only decoders */
-    if (!in_plugin->decode) {
+    /* only video decoders */
+    if (!in_plugin->decode || in_plugin->type != AVMEDIA_TYPE_VIDEO)
       goto next;
-    }
 
     /* no quasi-codecs, please */
     if (in_plugin->id == CODEC_ID_RAWVIDEO ||
